#ifndef Initialisierung_H
#define Initialisierung_H

#include <Fenster.h>
#include <Knopf.h>
#include <TextFeld.h>
#include <Schrift.h>
#include <initializer_list>
#include <AuswahlBox.h>
#include <Tabelle.h>
#include <Bild.h>
#include <Diagramm.h>
#include <Fortschritt.h>
#include <Liste.h>

using namespace Framework;

struct OBJTabelleSpalteIni
{
	char *name;
	int breite;
	int minBreite;
	int maxBreite;
};

#define ABSTYLE AuswahlBox::Style::Sichtbar | AuswahlBox::Style::Erlaubt | AuswahlBox::Style::Rahmen | AuswahlBox::Style::AuswahlBuffer | AuswahlBox::Style::MausBuffer | AuswahlBox::Style::MaxHöhe | AuswahlBox::Style::Hintergrund | AuswahlBox::Style::VScroll
#define OTSTYLE ObjTabelle::Style::Sichtbar | ObjTabelle::Style::Erlaubt | ObjTabelle::Style::Rahmen | ObjTabelle::Style::Raster

Knopf *initKnopf( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style, char *titel );
KontrollKnopf *initKontrollKnopf( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style, char *txt );
Fenster *initFenster( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style, char *titel );
TextFeld *initTextFeld( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style, char *txt );
BildO *initBildO( int x, int y, int br, int hö, __int64 style, Bild *b );
AuswahlBox *initAuswahlBox( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style, std::initializer_list< char * > values );
ObjTabelle *initObjTabelle( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style, std::initializer_list< OBJTabelleSpalteIni > spalten, int überschriftHöhe );
LDiag *initLinienDiagramm( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style, DiagDaten *data );
FBalken *initFBalken( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style );
AuswahlListe *initAuswahlListe( int x, int y, int br, int hö, Schrift *zSchrift, __int64 style, std::initializer_list< char * > values );
ZeichnungHintergrund *initZeichnungHintergrund( int x, int y, int br, int hö, __int64 style, int farbe );
void initToolTip( Zeichnung *obj, const char *txt, Schrift *schrift, Bildschirm *zBs );

#endif